@@ -46,10 +46,10 @@ wrf_get <- function(file = file.choose(), name = NA, as_raster = FALSE,
   if(name == 'time'){
     wrfchem <- ncdf4::nc_open(file)                                                     # nocov
     if(verbose)                                                                         # nocov
-      cat(paste0('reading Times from ', file,'\n'))                                     # nocov
+      cat(paste0('\nreading Times from ', file,'\n'))                                     # nocov
     TIME   <- ncvar_get(wrfchem,'Times')                                                # nocov
     TIME   <- as.POSIXlt(TIME, tz = "UTC", format="%Y-%m-%d_%H:%M:%OS", optional=FALSE) # nocov
-    cat('returning Times in POSIXct\n')                                                 # nocov
+    cat('\nreturning Times in POSIXct\n')                                                 # nocov
     return(TIME)                                                                        # nocov
   }
   if(verbose)
